@@ -57,7 +57,8 @@ class MultiUploadForm(forms.Form):
             'maxFileSize': multiuploader_settings[form_type]["MAX_FILE_SIZE"],
             'acceptFileTypes': format_file_extensions(multiuploader_settings[form_type]["FILE_TYPES"]),
             'maxNumberOfFiles': multiuploader_settings[form_type]["MAX_FILE_NUMBER"],
-            'allowedContentTypes': map(str.lower, multiuploader_settings[form_type]["CONTENT_TYPES"])
+            'allowedContentTypes': map(str.lower, multiuploader_settings[form_type]["CONTENT_TYPES"]),
+            'autoUpload': multiuploader_settings[form_type]["AUTO_UPLOAD"]
         }
 
         self._options = options
