@@ -7,37 +7,20 @@ from hashlib import sha1
 
 from django.db import models
 from django.conf import settings
+from django.core.urlresolvers import reverse
+from django.utils.safestring import mark_safe
 from django.utils.text import get_valid_filename
 from django.core.files.storage import default_storage
 from django.utils.translation import ugettext_lazy as _
 
+
+
 from multiuploader.utils import generate_safe_pk
 
-def get_filename(storage=default_storage):
-    def _filename(instance, filename):
-        make_filename_safe = instance.ModelSettings.make_filename_safe
-        upload_path = instance.ModelSettings.upload_path
-
-        if upload_path[-1] != '/':
-            upload_path += '/'
-
-        if make_filename_safe:
-            filename = get_valid_filename(os.path.basename(filename))
-            filename, ext = os.path.splitext(filename)
-            hash = sha1(str(time.time())).hexdigest()
-            fullname = os.path.join(upload_path, "%s.%s%s" % (filename, hash, ext))
-        else:
-            filename = get_valid_filename(os.path.basename(filename))
-            fullname = os.path.join(upload_path, filename)
-
-        return fullname
-
-    return _filename
 
 class BaseAttachment(models.Model):
     id = models.CharField(primary_key=True, max_length=255)
     filename = models.CharField(max_length=255, blank=False, null=False)
-
     upload_date = models.DateTimeField()
 
     @generate_safe_pk
@@ -56,6 +39,9 @@ class BaseAttachment(models.Model):
     class Meta:
         abstract = True
 
+    def __unicode__(self):
+        return u'%s' % self.filename
+
 class MultiuploaderFile(BaseAttachment):
     def _upload_to(instance, filename):
         upload_path = getattr(settings, 'MULTIUPLOADER_FILES_FOLDER', DEFAULTS.MULTIUPLOADER_FILES_FOLDER)
@@ -72,6 +58,10 @@ class MultiuploaderFile(BaseAttachment):
 
     file = models.FileField(upload_to=_upload_to, max_length=255)
 
+    def save(self, *args, **kwargs):
+        self.filename = os.path.basename(self.file.path)
+        return super(MultiuploaderFile, self).save(*args, **kwargs)
+
     class Meta:
         verbose_name = _('multiuploader file')
         verbose_name_plural = _('multiuploader files')
\ No newline at end of file
