@@ -8,6 +8,6 @@ urlpatterns = patterns('',
                        url(r'^multiuploader/$', 'multiuploader.views.multiuploader', name='multiuploader'),
                        url(r'^multiuploader_noajax/$', 'multiuploader.views.multiuploader', kwargs={"noajax": True},
                            name='multiploader_noajax'),
-                       url(r'^multiuploader_file/(?P<pk>\w+)/$', 'multiuploader.views.multi_show_uploaded',
+                       url(r'^multiuploader_file/(?P<pk>\w*)/$', 'multiuploader.views.multi_show_uploaded',
                            name='multiuploader_file_link')
 )
